@@ -38,7 +38,10 @@ from collections import defaultdict
 from argparse import ArgumentParser
 
 
-import sip
+try:
+    from PyQt5 import sip
+except ImportError:
+    import sip
 
 # pylint: disable=wrong-import-order
 
@@ -482,7 +485,7 @@ class KStandardAction:
 
         action = QAction(mainWindow)
         action.triggered.connect(slot)
-        action.setText(i18n('Configure &Kajongg'))
+        action.setText(i18n('Configure &Kajongg...'))
         action.setIcon(KIcon('configure'))
         action.setIconText(i18n('Configure'))
         actionCollection.addAction('options_configure', action)
@@ -1107,6 +1110,9 @@ class AboutKajonggDialog(KDialog):
     def __init__(self, parent):
         # pylint: disable=too-many-locals, too-many-statements
         from twisted import __version__
+
+        data = KGlobal.aboutData
+
         KDialog.__init__(self, parent)
         self.setCaption(i18n('About Kajongg'))
         self.setButtons(KDialog.Close)
@@ -1115,6 +1121,7 @@ class AboutKajonggDialog(KDialog):
         hLayout1.addWidget(IconLabel('kajongg', self))
         h1vLayout = QVBoxLayout()
         h1vLayout.addWidget(QLabel('Kajongg'))
+        h1vLayout.addWidget(QLabel(i18n('Version: %1', data.version)))
         h1vLayout.addWidget(QLabel(i18n('Protocol version %1', Internal.defaultPort)))
         underVersions = []
         try:
@@ -1146,8 +1153,6 @@ class AboutKajonggDialog(KDialog):
         vLayout.addLayout(hLayout1)
         tabWidget = QTabWidget()
 
-        data = KGlobal.aboutData
-
         aboutWidget = QWidget()
         aboutLayout = QVBoxLayout()
         aboutLabel = QLabel()
